@@ -150,11 +150,12 @@ class RideView(QtGui.QWidget):
       self.menu = menu
 
       refreshIcon = QtGui.QIcon(QtGui.QPixmap(self.IconPath('refresh.png')))
-      self.refreshAction = menu.addAction(refreshIcon, 'Rafraichir')
+      self.refreshAction = menu.addAction(refreshIcon, u'Rafraîchir')
       # self.refreshAction.setIconVisibleInMenu(True)
 
       refreshAutoIcon = QtGui.QIcon(QtGui.QPixmap(self.IconPath('refreshauto.png')))
-      self.refreshAutoAction = menu.addAction(refreshAutoIcon, 'Rafraichissement auto')
+      rr = self.parent.model.ttConf.refreshRate()
+      self.refreshAutoAction = menu.addAction(refreshAutoIcon, u'Rafraîchissement auto %s'%rr)
       # self.refreshAutoAction.setIconVisibleInMenu(True)
       self.refreshAutoAction.setCheckable(True)
 
@@ -199,9 +200,11 @@ class RideView(QtGui.QWidget):
       QtGui.QDesktopServices.openUrl( self.model.getUrl() )
 
    def Animate(self, variant):
+      #DebugLog("RideView::Animate %d"%variant.toSize().height())
       self.progress.setFixedHeight(variant.toSize().height())
 
    def AnimateFinished(self):
+      DebugLog("RideView::AnimateFinished")
       size = self.progress.size()
       if size.height()==0:
          self.progress.hide()
@@ -237,7 +240,7 @@ class RideView(QtGui.QWidget):
                self.SetLabel(irow, 0, line.train,        '#fff', color, 70,  90, self.font)
                self.SetLabel(irow, 1, line.heure,     '#FFCD00', color, 0,  0, self.font)
                self.SetLabel(irow, 2, line.destination,  '#fff', color, 400, 0, self.font, Qt.AlignLeft|Qt.AlignVCenter)
-               self.SetLabel(irow, 3, line.voie,         '#fff', color, 40,  50, self.font)
+               self.SetLabel(irow, 3, line.voie,         '#fff', color, 60,  50, self.font)
 
          irow += 1
 
@@ -256,8 +259,10 @@ class RideView(QtGui.QWidget):
          self.ShowInfo()
 
    def ShowInfo(self):
+      DebugLog("RideView::ShowInfo")
       size = self.progress.size()
       if not self.progress.isVisible():
+         DebugLog("not is Visible")
          self.progress.show()
          self.animate.setStartValue( size )
          self.animate.setEndValue( QtCore.QSize(size.width(), 96) )
